MockCMO = [
    "   CUSTO MARGINAL DE OPERACAO  ($/MWh)                                                                                                                                                                  \n",
    "   X------X----------X----------X----------X----------X----------X                                                                                                                                      \n",
    "     Ssis  Sem_01     Sem_02     Sem_03     Sem_04     Sem_05                                                                                                                                           \n",
    "   X------X----------X----------X----------X----------X----------X                                                                                                                                      \n",
    "    Pat_1    287.91     291.06     291.99     289.35     287.67                                                                                                                                         \n",
    "    Pat_2    287.27     289.42     290.16     287.72     283.62                                                                                                                                         \n",
    "    Pat_3    281.48     283.41     283.32     280.07     278.99                                                                                                                                         \n",
    "    Med_SE   284.12     286.88     287.26     284.37     282.32                                                                                                                                         \n",
    "    Pat_1    287.91     291.06     291.99     289.35     287.67                                                                                                                                         \n",
    "    Pat_2    287.27     289.42     290.16     287.72     283.62                                                                                                                                         \n",
    "    Pat_3    281.48     283.41     283.32     280.07     278.99                                                                                                                                         \n",
    "    Med_S    284.12     286.88     287.26     284.37     282.32                                                                                                                                         \n",
    "    Pat_1    287.91     291.06     291.99     289.35     287.67                                                                                                                                         \n",
    "    Pat_2    287.27     289.42     290.16     287.72     283.62                                                                                                                                         \n",
    "    Pat_3    281.48     283.41     283.32     280.07     278.99                                                                                                                                         \n",
    "    Med_NE   284.12     286.88     287.26     284.37     282.32                                                                                                                                         \n",
    "    Pat_1    287.91     291.06     291.99     289.35     287.67                                                                                                                                         \n",
    "    Pat_2    287.27     289.42     290.16     287.72     283.62                                                                                                                                         \n",
    "    Pat_3    281.48     283.41     283.32     280.07     278.99                                                                                                                                         \n",
    "    Med_N    284.12     286.88     287.26     284.37     282.32                                                                                                                                         \n",
    "    Pat_1    287.91     291.06     291.99     289.35     287.67                                                                                                                                         \n",
    "    Pat_2    287.27     289.42     290.16     287.72     283.62                                                                                                                                         \n",
    "    Pat_3    281.48     283.41     283.32     280.07     278.99                                                                                                                                         \n",
    "    Med_FC   284.12     286.88     287.26     284.37     282.32                                                                                                                                         \n",
    "   X------X----------X----------X----------X----------X----------X                                                                                                                                      \n",
]

MockGeracaoTermicaSubsistema = [
    "   GERACAO TERMICA NOS SUSBSISTEMAS (MWmed) p/ CGC                                                                                                                                                      \n",
    "   X------X----------X----------X----------X----------X----------X                                                                                                                                      \n",
    "     Ssis  Sem_01     Sem_02     Sem_03     Sem_04     Sem_05                                                                                                                                           \n",
    "   X------X----------X----------X----------X----------X----------X                                                                                                                                      \n",
    "     SE        5083.8     4804.5     4315.4     4632.2     4705.9                                                                                                                                       \n",
    "     S         1176.0     1521.0     1522.0     1522.0     1522.0                                                                                                                                       \n",
    "     NE        1938.1     1668.1     1622.6     1634.7     1634.7                                                                                                                                       \n",
    "     N         2790.4     2692.6     2817.3     2834.3     2683.0                                                                                                                                       \n",
    "     FC           0.0        0.0        0.0        0.0        0.0                                                                                                                                       \n",
    "   X------X----------X----------X----------X----------X----------X                                                                                                                                      \n",
]

MockCustoOperacaoValorEsperado = [
    "    CUSTO DE OPERACAO E VALOR ESPERADO DO C.FUTURO ( 1.000 $ )                                                                                                                                           ",
    "X------X------------X------------X------------X------------X------------X                                                                                                                            ",
    "           Sem_01       Sem_02       Sem_03       Sem_04       Sem_05                                                                                                                                ",
    "X------X------------X------------X------------X------------X------------X                                                                                                                            ",
    " *COP        90662.8      79546.7      81339.2      89975.9      85036.6                                                                                                                             ",
    " E(CF)   194072319.4  194414075.1  194755137.6  195088616.8  195427943.0                                                                                                                             "
    "X------X------------X------------X------------X------------X------------X  ",
]


MockVolumeUtilReservatorio = [
    "   VOLUME UTIL DOS RESERVATORIOS                                                                                                                                                                        \n",
    "   X----X------------X-------X------X------X------X------X------X                                                                                                                                       \n",
    "     No.  Usina        %V.U.          % V.U.  Final                                                                                                                                                     \n",
    "                       Inic.  Sem_01 Sem_02 Sem_03 Sem_04 Sem_05                                                                                                                                        \n",
    "   X----X------------X-------X------X------X------X------X------X                                                                                                                                       \n",
    "      1  CAMARGOS       25.3   24.9   27.5   30.4   35.1   39.2                                                                                                                                         \n",
    "      6  FURNAS         13.2   12.6   12.9   14.2   15.6   17.4                                                                                                                                         \n",
    "      7  M. DE MORAES   36.2   40.8   43.0   42.2   44.0   50.9                                                                                                                                         \n",
    "     14  CACONDE        38.0   38.2   40.4   42.5   45.8   47.9                                                                                                                                         \n",
    "     17  MARIMBONDO     23.1   28.2   32.6   41.6   51.9   58.0                                                                                                                                         \n",
    "     18  A. VERMELHA    23.7   20.9   21.0   18.6   20.4   28.9                                                                                                                                         \n",
    "     20  BATALHA        20.1   20.2   20.0   20.4   22.0   24.5                                                                                                                                         \n",
    "     21  SERRA FACAO    17.5   17.3   17.3   17.5   18.1   18.4                                                                                                                                         \n",
    "     24  EMBORCACAO     12.8   13.3   14.1   14.9   16.2   17.4                                                                                                                                         \n",
    "     25  NOVA PONTE     16.8   16.3   16.2   16.6   17.0   18.0                                                                                                                                         \n",
    "     26  MIRANDA        96.3  100.0  100.0   97.0  100.0  100.0                                                                                                                                         \n",
    "     27  CAPIM BRANC1   82.7  100.0  100.0  100.0  100.0  100.0                                                                                                                                         \n",
    "     29  CORUMBA IV     23.0   15.6   10.4    8.0    7.1    9.3                                                                                                                                         \n",
    "    203  CORUMBA III    22.5   43.0   44.4   34.6   31.2   17.2                                                                                                                                         \n",
    "     30  CORUMBA I      30.5   34.6   43.1   49.1   59.3   72.1                                                                                                                                         \n",
    "     31  ITUMBIARA      16.3   16.0   15.9   17.3   18.6   20.9                                                                                                                                         \n",
    "     33  SAO SIMAO      33.4   35.3   38.5   41.2   45.9   51.5                                                                                                                                         \n",
    "    290  ESPORA         25.0   28.9   34.6   41.6   49.0   56.5                                                                                                                                         \n",
    "    311  CACU           70.0   26.2    9.8   31.5   18.7   53.7                                                                                                                                         \n",
    "     34  I. SOLTEIRA    68.1   70.3   74.4   73.6   74.1   70.4                                                                                                                                         \n",
    "    118  BILLINGS       72.0   71.8   71.6   71.6   71.9   72.0                                                                                                                                         \n",
    "    117  GUARAPIRANGA   70.4   69.7   68.9   68.8   71.5   73.9                                                                                                                                         \n",
    "     37  BARRA BONITA   53.7   50.1   48.6   51.2   50.9   50.1                                                                                                                                         \n",
    "     40  PROMISSAO      42.9   36.1   31.0   29.0   32.0   42.4                                                                                                                                         \n",
    "     43  TRES IRMAOS    65.8   70.3   74.4   73.6   74.1   70.4                                                                                                                                         \n",
    "     47  A.A. LAYDNER   28.8   25.5   22.9   20.8   20.4   20.3                                                                                                                                         \n",
    "     49  CHAVANTES      22.4   22.2   23.2   24.4   25.5   25.2                                                                                                                                         \n",
    "     57  MAUA           51.9   51.0   46.1   40.7   38.0   34.3                                                                                                                                         \n",
    "     61  CAPIVARA       35.5   35.6   36.3   38.1   42.0   47.6                                                                                                                                         \n",
    "     66  ITAIPU          0.0  100.0  100.0  100.0  100.0  100.0                                                                                                                                         \n",
    "    120  JAGUARI        49.1   50.3   51.8   53.8   55.8   58.1                                                                                                                                         \n",
    "    121  PARAIBUNA      31.3   32.0   32.7   33.4   34.4   36.1                                                                                                                                         \n",
    "    122  SANTA BRANCA   43.4   48.7   56.9   65.7   73.5   77.6                                                                                                                                         \n",
    "    123  FUNIL          41.5   55.2   55.8   57.1   62.0   62.0                                                                                                                                         \n",
    "    124  LAJES          83.8   85.4   85.6   85.7   86.7   89.1                                                                                                                                         \n",
    "    135  P. ESTRELA     37.6  100.0   33.3   49.7  100.0  100.0                                                                                                                                         \n",
    "    278  MANSO          52.6   51.9   51.6   52.4   53.2   55.0                                                                                                                                         \n",
    "    276  RONDON II      30.1   25.1   20.5   17.7   13.5   11.3                                                                                                                                         \n",
    "    279  SAMUEL         18.9   26.7   32.0   38.1   44.3   50.4                                                                                                                                         \n",
    "    227  SINOP          50.0   29.8   17.3    8.7    7.3   11.3                                                                                                                                         \n",
    "     71  STA CLARA PR   51.3   47.4   40.1   33.0   23.8    8.2                                                                                                                                         \n",
    "     73  JORDAO        100.0  100.0  100.0  100.0  100.0  100.0                                                                                                                                         \n",
    "     74  G.B. MUNHOZ    20.8   17.2   15.0   13.8   15.5   17.4                                                                                                                                         \n",
    "     76  SEGREDO        35.4   77.6  100.0   92.3   83.7  100.0                                                                                                                                         \n",
    "     77  SLT.SANTIAGO   19.0   18.0   16.8   19.2   21.5   24.1                                                                                                                                         \n",
    "     86  BARRA GRANDE   19.3   16.1   12.7   11.6   12.3   15.3                                                                                                                                         \n",
    "     89  GARIBALDI      53.3   24.9   19.1   41.8   40.2   85.3                                                                                                                                         \n",
    "     90  CAMPOS NOVOS   50.9   69.2   67.5   47.3   40.4   31.2                                                                                                                                         \n",
    "     91  MACHADINHO     17.8   17.1   22.3   26.5   31.2   36.4                                                                                                                                         \n",
    "     93  PASSO FUNDO    29.6   30.1   30.2   30.4   31.3   32.5                                                                                                                                         \n",
    "     95  QUEBRA QUEIX   65.7  100.0  100.0   81.7   89.2   82.3                                                                                                                                         \n",
    "    110  ERNESTINA      99.6    0.0    0.0    0.0    0.0    0.0                                                                                                                                         \n",
    "    111  PASSO REAL     74.5   80.8   79.3   78.2   77.6   77.7                                                                                                                                         \n",
    "    115  G.P. SOUZA     23.8   26.9   30.6   33.6   38.2   44.7                                                                                                                                         \n",
    "    148  IRAPE          22.9   22.9   23.1   24.6   28.9   34.5                                                                                                                                         \n",
    "    155  RETIRO BAIXO   52.4  100.0  100.0  100.0   77.7  100.0                                                                                                                                         \n",
    "    156  TRES MARIAS    57.0   57.5   59.2   61.2   63.5   67.0                                                                                                                                         \n",
    "    162  QUEIMADO       27.8   26.4   24.0   20.4   17.8   17.2                                                                                                                                         \n",
    "    169  SOBRADINHO     28.8   27.8   26.6   26.1   25.9   26.1                                                                                                                                         \n",
    "    172  ITAPARICA      37.5   43.7   44.5   42.1   39.6   37.2                                                                                                                                         \n",
    "    189  P. CAVALO      78.1   69.1   59.1   48.6   39.6   31.3                                                                                                                                         \n",
    "    190  B. ESPERANCA   18.4   17.9   19.6   22.5   27.8   35.5                                                                                                                                         \n",
    "    251  SERRA MESA      9.4    8.8    8.3    8.3    8.7    9.4                                                                                                                                         \n",
    "    257  PEIXE ANGIC    18.2    5.0   10.5    0.0    0.0    0.0                                                                                                                                         \n",
    "    272  CURUA-UNA      22.3   30.2   34.0   36.7   37.3   38.3                                                                                                                                         \n",
    "    275  TUCURUI        17.3   19.8   22.1   24.6   26.3   30.0                                                                                                                                         \n",
    "    277  BALBINA        24.6   27.1   28.2   28.9   30.3   31.8                                                                                                                                         \n",
    "   X----X------------X-------X------X------X------X------X------X                                                                                                                                       \n",
]

MockEnergiaArmazenadaREE = [
    "   ENERGIA ARMAZENADA NOS REEs (% EARM_MAXIMA)                                                                                                                                                          \n",
    "   X------------X----X----X-------X------X------X------X------X------X                                                                                                                                  \n",
    "       REE        No  Sis   Inic.  Sem_01 Sem_02 Sem_03 Sem_04 Sem_05                                                                                                                                   \n",
    "   X------------X----X----X-------X------X------X------X------X------X                                                                                                                                  \n",
    "     SUDESTE       1    1    19.5   19.4   19.4   19.7   20.6   21.8                                                                                                                                    \n",
    "     MADEIRA       6    1    19.1   24.2   27.6   32.0   36.3   40.9                                                                                                                                    \n",
    "     TPIRES        7    1    49.0   28.9   16.6    8.4    7.0   10.9                                                                                                                                    \n",
    "     ITAIPU        5    1     0.0  100.0  100.0  100.0  100.0  100.0                                                                                                                                    \n",
    "     PARANA       10    1    20.0   20.1   20.8   21.9   23.5   25.7                                                                                                                                    \n",
    "     PRNPANEMA    12    1    29.3   28.2   27.6   27.7   29.0   30.6                                                                                                                                    \n",
    "     SUL           2    2    40.5   39.6   38.7   38.3   39.0   41.1                                                                                                                                    \n",
    "     IGUACU       11    2    21.7   21.1   20.1   19.5   20.4   22.3                                                                                                                                    \n",
    "     NORDESTE      3    3    37.6   37.6   37.4   37.5   37.9   39.0                                                                                                                                    \n",
    "     NORTE         4    4    14.6   15.3   16.2   17.3   18.5   20.9                                                                                                                                    \n",
    "     BMONTE        8    4    18.6   25.9   29.5   32.1   32.6   33.6                                                                                                                                    \n",
    "     MAN-AP        9    4    22.4   24.8   25.8   26.5   27.9   29.3                                                                                                                                    \n",
    "   X------------X----X----X-------X------X------X------X------X------X                                                                                                                                  \n",
]

MockEnergiaArmazenadaSubsistema = [
    "   ENERGIA ARMAZENADA NOS SUBSISTEMAS (% EARM_MAXIMA)                                                                                                                                                   \n",
    "   X------------X----X-------X------X------X------X------X------X                                                                                                                                       \n",
    "     SUBSISTEMA   No   Inic.  Sem_01 Sem_02 Sem_03 Sem_04 Sem_05                                                                                                                                        \n",
    "   X------------X----X-------X------X------X------X------X------X                                                                                                                                       \n",
    "         SE        1    20.4   20.7   21.1   21.9   23.3   25.2                                                                                                                                         \n",
    "         S         2    30.6   29.9   28.9   28.4   29.2   31.2                                                                                                                                         \n",
    "         NE        3    37.6   37.6   37.4   37.5   37.9   39.0                                                                                                                                         \n",
    "         N         4    15.0   15.8   16.7   17.8   19.0   21.4                                                                                                                                         \n",
    "   X------------X----X-------X------X------X------X------X------X                                                                                                                                       \n",
]

MockSumario = (
    MockCMO
    + MockGeracaoTermicaSubsistema
    + MockCustoOperacaoValorEsperado
    + MockVolumeUtilReservatorio
    + MockEnergiaArmazenadaREE
    + MockEnergiaArmazenadaSubsistema
)
